class BlockType:
    IMPORT = "import"
    FUNCTION = "function"
    CLASS = "class"
    VALUE = "value"
    COMMENT = "comment"
    OTHER = "other"
